@@ -163,6 +163,12 @@ class BaseProtocol:
                 except asyncio.TimeoutError as te:
                     self.logger.exception("Tiempo fuera en intento de cerrar conexión %s, station %s" %(te, self.station))
                     await asyncio.sleep(10)
+                except ascyncio.IncompletereadError as e:
+                    self.logger.exception("Excepción por lectura incomplete  %s, station %s"%(e, self.station))
+                    await asyncio.sleep(10)
+                except ascyncio.CanceledError as e:
+                    self.logger.exception("Excepción por error de cancelación  %s, station %s"%(e, self.station))
+                    await asyncio.sleep(10)
                 except (ConnectionResetError, ConnectionAbortedError) as conn_error:
                     self.logger.exception("Excepción por desconexión %s, station %s"%(conn_error, self.station))
                     await asyncio.sleep(10)                    
@@ -222,7 +228,20 @@ class BaseProtocol:
         reader = self.clients[idc]['reader']
         writer = self.clients[idc]['writer']
         writer.close()
-        await writer.wait_closed()
+        try:
+            await wait_for(writer.wait_closed(), timeout=10)
+        except asyncio.TimeoutError as te:
+            print("Close->Error Timeout al leer %d bytes en %s" %(n, self.station))
+            self.logger.exception("Station %s, Tiempo fuera al leer en readbytes, %s"%(self.station,te))
+        except asyncio.IncompleteReadError as ir:
+            print("Close_>Incomplete read, station %s" %self.station, reader, n)
+            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+        except (ConnectionResetError, ConnectionAbortedError) as conn_error:
+            self.logger("Close->Excepción por desconexión al intentar leer %s"%conn_error)
+        except Exception as e:
+            print("Excepción no considerada")
+            self.logger("Close->Excepción no considerada al intentar leer%s"%e)
+
 
     async def stop(self):
         for idc in self.clients:
@@ -242,15 +261,14 @@ class BaseProtocol:
                 return None
         except asyncio.IncompleteReadError as ir:
             print("Incomplete read, station %s" %self.station, reader, n)
-            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(
-                n, self.station,ir))
+            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
             return None
         except (ConnectionResetError, ConnectionAbortedError) as conn_error:
-            self.logger.exception("Excepción por desconexión al intentar leer %s"%conn_error)
+            self.logger("Excepción por desconexión al intentar leer %s"%conn_error)
             return None
         except Exception as e:
             print("Excepción no considerada")
-            self.logger.exception("Excepción no considerada al intentar leer%s"%e)
+            self.logger("Excepción no considerada al intentar leer%s"%e)
             return None
         
     async def get_message_header(self, idc):
